@@ -1,6 +1,6 @@
 ;; jde-ant.el --- Use Apache Ant to build your JDE projects
 
-;; $Revision: 1.54 $ $Date: 2002/12/14 18:37:36 $ 
+;; $Revision: 1.76 $ $Date: 2004/11/20 05:51:04 $ 
 
 ;;
 ;; Author: Jason Stell | jason.stell@globalone.net
@@ -36,7 +36,7 @@
 ;;
 ;; Notes:
 ;; -- The JDE (Java Development Environment for Emacs) can be
-;;    downloaded at http://sunsite.auc.dk/jde/
+;;    downloaded at http://jdee.sunsite.dk
 ;;
 ;; -- Apache Ant is a Java & XML build system that can be downloaded 
 ;;    at http://jakarta.apache.org/ant/
@@ -172,8 +172,8 @@ non-nil, the jde-ant-build command prompts you for the additional arguments."
   :group 'jde-ant
   :type 'boolean)
 
-;; (defvar jde-ant-interactive-args-history nil
-;; "History of targets entered in the minibuffer.")
+(defvar jde-ant-interactive-args-history nil
+"History of targets entered in the minibuffer.")
 
 (defvar jde-ant-buildfile-history nil
  "History of targets entered in the minibuffer.")
@@ -222,7 +222,7 @@ option has no effect if jde-ant-read-target is nil."
 
 (defcustom jde-ant-build-hook '(jde-compile-finish-kill-buffer
                                 jde-compile-finish-refresh-speedbar
-                                jde-compile-finish-flush-completion-cache)
+                                jde-compile-finish-update-class-info)
   "*List of hook functions run by `jde-ant-build' (see `run-hooks'). Each
 function should accept two arguments: the compilation buffer and a string
 describing how the compilation finished"
@@ -245,30 +245,40 @@ variable ANT_HOME."
   (when (null buildfile)
     (setq buildfile jde-ant-buildfile))
     
-  (let* ((ANT_HOME_ENV (getenv "ANT_HOME"))
-         (ant-home (if (string= "" jde-ant-home)
-                       (if ANT_HOME_ENV (jde-normalize-path ANT_HOME_ENV))
-                     (jde-normalize-path jde-ant-home)))
-         (delimiter (if (string= (car jde-ant-invocation-method) "Java")
+  (let* ((ant-home (jde-ant-get-ant-home))
+         (delimiter (if (or
+                         (string= (car jde-ant-invocation-method) "Java")
+                         (and (string= (car jde-ant-invocation-method)
+                                       "Script")
+                              (not (featurep 'xemacs))))
                         "'"
                       "\""))
+         (ant-program (if (or (string-match "\\\\" jde-ant-program)
+                              (string-match "/" jde-ant-program))
+                          (jde-normalize-path jde-ant-program)
+                        jde-ant-program))
          (ant-command
           (concat 
-           (if (string= (car jde-ant-invocation-method) "Script")
-	       jde-ant-program)
+           (if (string= (car jde-ant-invocation-method) "Script") ant-program)
            (if (string= (car jde-ant-invocation-method) "Java")
-               (concat 
+               (concat
 		(jde-get-jdk-prog 'java)
 		" -classpath "
-                (if (and (eq system-type 'windows-nt)
+                (if (and (or (eq system-type 'windows-nt)
+			      (eq system-type 'cygwin32))
                          (string-match "sh$" shell-file-name))
                     delimiter)
                 (jde-ant-build-classpath)
-               (if (and (eq system-type 'windows-nt)
-                        (string-match "sh$" shell-file-name))
-                   delimiter)))
-          " -Dant.home="
-          ant-home
+	    (if (and (or (eq system-type 'windows-nt)
+			 (eq system-type 'cygwin32))
+		     (string-match "sh$" shell-file-name))
+		delimiter)))
+	   (if ant-home 
+	       (concat 
+		" -Dant.home=" 
+		(if (string-match " " ant-home) ;; Quote path if it
+		    (concat "\"" ant-home "\"") ;; contains a space.
+		  ant-home)))
           (if (string= (car jde-ant-invocation-method) "Java")
               (concat
                " "
@@ -297,9 +307,7 @@ variable ANT_HOME."
   "Build the classpath we should use when running ant.  This returns a
 classpath normalized with `jde-build-classpath'."
 
-  (let* ((ant-home (if (string= "" jde-ant-home)
-                       (jde-normalize-path (getenv "ANT_HOME"))
-                     (jde-normalize-path jde-ant-home)))
+  (let* ((ant-home (jde-ant-get-ant-home))
          classpath)
 
     (setq classpath (append (list (expand-file-name "lib" ant-home)
@@ -311,18 +319,27 @@ classpath normalized with `jde-build-classpath'."
 
     (jde-build-classpath classpath)))
 
-(defun jde-ant-interactive-get-buildfile()
+(defun jde-ant-get-ant-home ()
+  "Calculate an appropriate ant home."
+  (let ((ant-home
+	 (if (string= jde-ant-home "")
+	     (getenv "ANT_HOME")
+	   jde-ant-home)))
+    (if ant-home
+	(jde-normalize-path ant-home))))
+
+(defun jde-ant-interactive-get-buildfile ()
   "Get a buildfile interactively.  This is used so that code that needs to read
   a buildfile from interactive can share the same type of behavior.  This will
   return a new filename which points to the build.xml file to use."
 
-  (let(buildfile)
+  (let (buildfile)
 
     (if jde-ant-read-buildfile
         ;;read the buildfile from the user.
 
         ;;figure out which directory to execute from.
-        (let(prompt-directory prompt-filename)
+        (let (prompt-directory prompt-filename)
 
           (if jde-ant-interactive-buildfile
               (progn
@@ -364,45 +381,46 @@ classpath normalized with `jde-build-classpath'."
   "Build the current project using Ant.  If interactive, we try to prompt the
   user for certain variables.."
   (interactive
-   (let (buildfile history target interactive-args)
-     
-     ;;build up the list of args we should use
-
-     ;;get the buildfile.
-     (setq buildfile (jde-ant-interactive-get-buildfile))
-
-     ;; Getting the history for the proper buildfile
-     (setq history (jde-ant-get-from-history buildfile))
-     
-     ;;get the target using completion.
-     (if jde-ant-read-target
-         (if jde-ant-complete-target
-             (setq target (completing-read
-                           "Target to build: "
-                           (jde-ant-get-target-alist buildfile)
-                           nil
-                           t
-                           (car history)
-                           'history))
-
-           ;;without using completion... read the target as a string.
-           (setq target (read-from-minibuffer
-                         "Target to build: "
-                         (car history)
-                         nil
-                         nil
-                         'history))))
+   (let* ((buildfile (jde-ant-interactive-get-buildfile))
+	  (build-history (jde-ant-get-from-history buildfile))
+	  (targets 
+	   (if jde-ant-read-target
+	       (if jde-ant-complete-target
+		   (if (fboundp 'completing-read-multiple)
+		       (completing-read-multiple
+			"Target to build: "
+			(jde-ant-get-target-alist buildfile)
+			nil
+			nil
+			(car build-history)
+			'build-history)
+		     (list (completing-read
+			    "Target to build: "
+			    (jde-ant-get-target-alist buildfile)
+			    nil
+			    t
+			    (car build-history)
+			    'build-history)))
+		 (list (read-from-minibuffer
+			"Target to build: "
+			(car build-history)
+			nil
+			nil
+			'build-history)))))
+	  (target 
+	   (jde-ant-escape (mapconcat 'identity targets " ")))
+	  (interactive-args
+	   (if jde-ant-read-args
+	       (read-from-minibuffer
+		"Additional build args: "
+		(nth 0 jde-ant-interactive-args-history)
+		nil nil
+		'(jde-ant-interactive-args-history . 1)))))
 
+               
      ;; Setting the history for future use
-     (jde-ant-add-to-history buildfile history)
+     (jde-ant-add-to-history buildfile build-history)
      
-     (setq target (jde-ant-escape target))
-     (if jde-ant-read-args
-         (setq interactive-args (read-from-minibuffer
-                                 "Additional build args: "
-                                 (nth 0 jde-ant-interactive-args-history)
-                                 nil nil
-                                 '(jde-ant-interactive-args-history . 1))))
 
      ;;some of these global variables are defaults.  We should restore then for
      ;;every request.  IE jde-ant-interactive-target and
@@ -414,8 +432,9 @@ classpath normalized with `jde-build-classpath'."
      ;;This should be a list of buildfile, target and optional-args.
      (list buildfile target interactive-args)))
   
-  (let ((compile-command (jde-build-ant-command target
-                                                interactive-args buildfile)))
+  (let ((compile-command 
+	 (jde-build-ant-command target interactive-args buildfile))
+	process-connection-type)
 
     (when compile-command
       ;; Force save-some-buffers to use the minibuffer
@@ -447,7 +466,8 @@ classpath normalized with `jde-build-classpath'."
                                                    compile-command)))
             (jde-ant-compile-internal compile-command 
                                       "No more errors"))
-        (compile-internal compile-command "No more errors")))))
+        (let ((default-directory (jde-ant-get-default-directory)))
+          (compile-internal compile-command "No more errors"))))))
 
 (defvar jde-ant-comint-filter nil)
 
@@ -484,20 +504,26 @@ and there are no more errors. "
       (kill-all-local-variables))
 	(setq error-regexp-alist compilation-error-regexp-alist)
 	(setq enter-regexp-alist
-              (if (not jde-xemacsp) compilation-enter-directory-regexp-alist))
+              (if (boundp 'compilation-enter-directory-regexp-alist)
+                  compilation-enter-directory-regexp-alist))
 	(setq leave-regexp-alist
-              (if (not jde-xemacsp) compilation-leave-directory-regexp-alist))
+              (if (boundp 'compilation-leave-directory-regexp-alist)
+                  compilation-leave-directory-regexp-alist))
 	(setq file-regexp-alist
-              (if (not jde-xemacsp) compilation-file-regexp-alist))
+              (if (boundp 'compilation-file-regexp-alist)
+                  compilation-file-regexp-alist))
 	(setq nomessage-regexp-alist
-              (if (not jde-xemacsp) compilation-nomessage-regexp-alist))
+              (if (boundp 'compilation-nomessage-regexp-alist)
+                  compilation-nomessage-regexp-alist))
   
         (let* (proc (thisdir (jde-ant-get-default-directory)) outwin)
           (save-excursion
             ;; Clear out the compilation buffer and make it writable.
-            (if (not (bsh-running-p))
-                (bsh-eval (jde-create-prj-values-str)))
-            (setq proc (bsh-get-process))
+            (if (not (jde-bsh-running-p))
+                (progn
+                  (bsh-launch (oref 'jde-bsh the-bsh))
+                  (bsh-eval (oref 'jde-bsh the-bsh) (jde-create-prj-values-str))))
+            (setq proc (bsh-get-process (oref 'jde-bsh the-bsh)))
             (set-buffer outbuf)
             (compilation-mode)
             (setq buffer-read-only nil)
@@ -549,49 +575,50 @@ and there are no more errors. "
 (defun jde-ant-filter (proc string) 
   "This filter prints out the result of the process without buffering.
 The result is inserted as it comes in the compilation buffer."
-  (with-current-buffer (get-buffer "*compilation*")
-    (let ((stack-trace (string-match "java.lang.SecurityException" string))
-          (end-of-result (string-match ".*bsh % " string))
-          (win (get-buffer-window "*compilation*"))
-          )
+  (let ((compilation-buffer (get-buffer "*compilation*")))
+    (if (not (null compilation-buffer))
+        (with-current-buffer compilation-buffer
+          (let ((stack-trace
+                 (string-match "java.lang.SecurityException" string))
+                (end-of-result (string-match ".*bsh % " string))
+                (win (get-buffer-window "*compilation*")))
       
-      (save-excursion
-        ;;Insert the text, advancing the process marker
-        (goto-char (point-max))
+            (save-excursion
+              ;;Insert the text, advancing the process marker
+              (goto-char (point-max))
         
-        ;;if the security exception has been thrown set the
-        ;;jde-ant-passed-security-exception flag and filter the stack trace out
-        ;;of the ouput
-        (if stack-trace 
-            (progn
-              (setq jde-ant-passed-security-exception t)
-              (insert (substring string 0 stack-trace))
-              (set-buffer-modified-p nil)
-              (compilation-mode "Compilation")
-              (jde-ant-set-build-status (buffer-string))
-              (jde-ant-handle-exit)))
-        
-        (if end-of-result
-            (progn
-              (if (not jde-ant-passed-security-exception)
-                  (progn 
-                    (insert (substring string 0 end-of-result))
+              ;;if the security exception has been thrown set the
+              ;;jde-ant-passed-security-exception flag and filter the stack
+              ;;trace out of the ouput
+              (if stack-trace 
+                  (progn
+                    (setq jde-ant-passed-security-exception t)
+                    (insert (substring string 0 stack-trace))
                     (set-buffer-modified-p nil)
-                    (compilation-mode "Compilation")
+                    (compilation-mode)
                     (jde-ant-set-build-status (buffer-string))
                     (jde-ant-handle-exit)))
-              (set-process-filter proc jde-ant-comint-filter)))
-        (if (and (not end-of-result)
-                 (not jde-ant-passed-security-exception))
-            (insert string)))
-    (if (not jde-xemacsp)
-          (if compilation-scroll-output
-              (save-selected-window
-                (if win
-                    (progn 
-                      (select-window win)
-                      (goto-char (point-max))))
-                (sit-for 0)))))))
+        
+              (if end-of-result
+                  (progn
+                    (if (not jde-ant-passed-security-exception)
+                        (progn 
+                          (insert (substring string 0 end-of-result))
+                          (set-buffer-modified-p nil)
+                          (compilation-mode)
+                          (jde-ant-set-build-status (buffer-string))
+                          (jde-ant-handle-exit)))
+                    (set-process-filter proc jde-ant-comint-filter)))
+              (if (and (not end-of-result)
+                       (not jde-ant-passed-security-exception))
+                  (insert string)))
+            (if (not jde-xemacsp)
+                (if compilation-scroll-output
+                    (save-selected-window
+                      (if win
+                          (progn 
+                            (select-window win)
+                            (goto-char (point-max))))))))))))
 
 (defun jde-ant-handle-exit ()
   "Handles the compilation exit"
@@ -664,7 +691,7 @@ Returns nil if it cannot find a project file in DIR or an ascendant directory."
       default-directory
     jde-ant-working-directory))
 
-(defun jde-ant-add-to-history (buildfile history)
+(defun jde-ant-add-to-history (buildfile build-history)
   (let ((temp (nth 0 jde-ant-interactive-target-history))
         (index -1) (found nil))
     (while (and temp (not found))
@@ -673,11 +700,11 @@ Returns nil if it cannot find a project file in DIR or an ascendant directory."
       (if (string= (car temp) buildfile)
 	  (setq found t)))
     (if found
-        (setcdr temp history)
+        (setcdr temp build-history)
       (setq jde-ant-interactive-target-history 
             (append 
              jde-ant-interactive-target-history 
-             (list (list buildfile (car history))))))))
+             (list (list buildfile (car build-history))))))))
 
 (defun jde-ant-get-from-history (buildfile)
   (let ((temp (nth 0 jde-ant-interactive-target-history))
@@ -701,6 +728,88 @@ Returns nil if it cannot find a project file in DIR or an ascendant directory."
 
 ;;
 ;; $Log: jde-ant.el,v $
+;; Revision 1.76  2004/11/20 05:51:04  paulk
+;; Fix regression in jde-ant-build command. Thanks to Jon Schewe.
+;;
+;; Revision 1.75  2004/11/16 13:48:43  jslopez
+;; Fixes typo, indentity->identity.
+;;
+;; Revision 1.74  2004/11/16 05:34:48  paulk
+;; Updated jde-ant-build to force use of pipes on Linux to interact with Ant. Also, simplified the code.
+;;
+;; Revision 1.73  2004/08/21 04:31:55  paulk
+;; Update the wizard class list after building a project.
+;;
+;; Revision 1.72  2004/07/01 14:04:39  jslopez
+;; Compatibility fix for emacs in CVS. Replaces jde-xemacsp check for boundp for
+;; the following variables: compilation-nomessage-regexp-alist,
+;; compilation-file-regexp-alist, compilation-leave-directory-regexp-alist,
+;; compilation-enter-directory-regexp-alist. Uses the compilation-mode without a
+;; parameter. The emacs in CVS does not contain the variables, or the parameter
+;; for compilation mode.
+;;
+;; Revision 1.71  2004/05/28 04:42:49  paulk
+;; Quote ant-home on the command line if it contains a space.
+;;
+;; Revision 1.70  2004/02/09 05:00:54  paulk
+;; Setting jde-ant-working-directory now works when invoking ant via a script or a vm.
+;; Thanks to Stan Lanning.
+;;
+;; Revision 1.69  2003/12/06 15:50:29  jslopez
+;; Fixes problem where jde-ant-program was being normalized unless it was set to
+;; ant or ant.bat. Now it only gets normalized if it contains '/' or a '\'.
+;;
+;; Revision 1.68  2003/10/19 14:25:32  jslopez
+;; Removes sit-for from jde-ant-filter. It causes the tool-bar and menu bar to
+;; redisplay annoyingly, plus it is not needed.
+;;
+;; Revision 1.67  2003/10/19 14:19:34  jslopez
+;; Fixes error in the jde-ant-filter.
+;;
+;; Revision 1.66  2003/06/24 13:00:51  paulk
+;; Fixed bug that caused noncompleting prompting for target to fail. Thanks to Christian Schmitt.
+;;
+;; Revision 1.65  2003/05/15 03:28:21  paulk
+;; Fix jde-ant-get-ant-home.
+;;
+;; Revision 1.64  2003/03/28 05:33:29  andyp
+;; XEmacs optimizations for JDEbug and efc.
+;;
+;; Revision 1.63  2003/03/04 10:15:07  paulk
+;; Updated to use the new bsh-get-process method provided
+;; by bsh to get its process. This is necessary to insulate
+;; clients from the fact that bsh now uses a bsh-buffer
+;; object to wrap the Emacs Lisp buffer object that specifies
+;; the associated process.
+;;
+;; Revision 1.62  2003/02/28 15:33:54  jslopez
+;; Adds support to jde-ant-complete-target to complete multiple targets.
+;;
+;; Revision 1.61  2003/02/17 21:38:04  jslopez
+;; Fixes regression bug.
+;;
+;; Revision 1.60  2003/02/17 08:13:05  paulk
+;; Changes required to support new package-independent version of beanshell.el
+;;
+;; Revision 1.59  2003/01/31 21:58:31  jslopez
+;; Fixes regression bug for XEmacs. "'" Causes in XEmacs not to be able to
+;; find the buildfile.
+;;
+;; Revision 1.58  2003/01/23 02:45:26  jslopez
+;; Fixes bug when using ant.bat, double quotes seem to cause problems.
+;; Fix to use jde-normalize-path when jde-ant-program is not ant or ant.bat.
+;;
+;; Revision 1.57  2003/01/22 03:23:39  jslopez
+;; Normalizes jde-ant-program.
+;;
+;; Revision 1.56  2003/01/21 13:39:13  jslopez
+;; XEmacs compatibility fix, history seems to be a reserve word
+;; in XEmacs.
+;;
+;; Revision 1.55  2003/01/04 17:31:09  jslopez
+;; Fixes regression bug.
+;; Uncomments jde-ant-interactive-args-history definition.
+;;
 ;; Revision 1.54  2002/12/14 18:37:36  jslopez
 ;; Fixes regression bug.
 ;;
