@@ -1,7 +1,7 @@
 ;;; JDE-CHECKSTYLE.EL --- Checkstyle interface for JDE
-;; $Revision: 1.16 $ $Date: 2003/11/05 08:33:59 $
+;; $Revision: 1.19 $ $Date: 2004/08/01 12:25:29 $
 
-;; Copyright (C) 2001, 2002, 2003 Markus Mohnen and Paul Kinnucan
+;; Copyright (C) 2001, 2002, 2003, 2004 Markus Mohnen and Paul Kinnucan
 
 ;; Authors: Markus Mohnen and Paul Kinnucan
 ;; Maintainers: Markus Mohnen and Paul Kinnucan
@@ -28,7 +28,7 @@
 ;; LCD Archive Entry:
 ;; jde-checkstyle|Markus Mohnen|
 ;; |Checkstyle interface for JDE
-;; |$Date: 2003/11/05 08:33:59 $|$Revision: 1.16 $|~/packages/jde-checkstyle.el
+;; |$Date: 2004/08/01 12:25:29 $|$Revision: 1.19 $|~/packages/jde-checkstyle.el
 
 ;;; Commentary:
 
@@ -175,6 +175,16 @@ buffer."
 		  (file :menu-tag "Source Directory" :tag "Path")))
 
 
+;; (makunbound 'jde-checkstyle-finish-hook)
+(defcustom jde-checkstyle-finish-hook 
+  '(jde-compile-finish-kill-buffer)
+  "List of functions to be invoked when CheckStyle terminates.  Each
+function should accept two arguments: the compilation buffer and a
+string describing how the compilation finished."
+  :group 'jde-checkstyle
+  :type 'hook)
+
+
 ;; (makunbound 'jde-checkstyle-source-file-extension)
 (defcustom jde-checkstyle-source-file-extension nil
   "*Extension of Java source files (if not java)."
@@ -217,10 +227,14 @@ buffer."
   (save-excursion
     (let ((buf (get-buffer-create "*check style*"))
 	  (error-regexp-alist compilation-error-regexp-alist)
-	  (enter-regexp-alist (if (not jde-xemacsp) compilation-enter-directory-regexp-alist))
-	  (leave-regexp-alist (if (not jde-xemacsp) compilation-leave-directory-regexp-alist))
-	  (file-regexp-alist (if (not jde-xemacsp) compilation-file-regexp-alist))
-	  (nomessage-regexp-alist (if (not jde-xemacsp) compilation-nomessage-regexp-alist))
+	  (enter-regexp-alist (if (boundp 'compilation-enter-directory-regexp-alist)
+                                  compilation-enter-directory-regexp-alist))
+	  (leave-regexp-alist (if (boundp 'compilation-leave-directory-regexp-alist)
+                                  compilation-leave-directory-regexp-alist))
+	  (file-regexp-alist (if (boundp 'compilation-file-regexp-alist)
+                                 compilation-file-regexp-alist))
+	  (nomessage-regexp-alist (if (boundp 'compilation-nomessage-regexp-alist)
+                                      compilation-nomessage-regexp-alist))
 	  (parser compilation-parse-errors-function)
 	  (error-message "No further errors")
 	  (thisdir default-directory))
@@ -255,8 +269,12 @@ buffer."
       (erase-buffer)
       (buffer-enable-undo (current-buffer))
 
-      (compilation-mode "Check Style")
+      (compilation-mode)
 
+      (set (make-local-variable 'compilation-finish-function)
+	   (lambda (buf msg) 
+	     (run-hook-with-args 'jde-checkstyle-finish-hook buf msg)
+	     (setq compilation-finish-function nil)))
       (set (make-local-variable 'compilation-parse-errors-function) parser)
       (set (make-local-variable 'compilation-error-message) error-message)
       (set (make-local-variable 'compilation-error-regexp-alist)
@@ -410,6 +428,20 @@ history enabled."
 (provide 'jde-checkstyle)
 
 ;; $Log: jde-checkstyle.el,v $
+;; Revision 1.19  2004/08/01 12:25:29  paulk
+;; Removed optional mode name from call to compilation-mode in jde-checkstyle-create-checker-buffer. This is necessary for compatibility with the latest Emacs, which no longer accepts the optional argument.
+;;
+;; Revision 1.18  2004/07/01 14:04:39  jslopez
+;; Compatibility fix for emacs in CVS. Replaces jde-xemacsp check for boundp for
+;; the following variables: compilation-nomessage-regexp-alist,
+;; compilation-file-regexp-alist, compilation-leave-directory-regexp-alist,
+;; compilation-enter-directory-regexp-alist. Uses the compilation-mode without a
+;; parameter. The emacs in CVS does not contain the variables, or the parameter
+;; for compilation mode.
+;;
+;; Revision 1.17  2004/02/02 05:32:50  paulk
+;; Added jde-checkstyle-finish-hook. Thanks to Len Trigg.
+;;
 ;; Revision 1.16  2003/11/05 08:33:59  paulk
 ;; Cosmetic changes.
 ;;
@@ -487,4 +519,4 @@ history enabled."
 ;; 
 ;; Version: 1.0
 
-;;; JDE-CHECKSTYLE.EL ends here
\ No newline at end of file
+;;; JDE-CHECKSTYLE.EL ends here
