@@ -1,13 +1,13 @@
 ;;; jde-java-font-lock.el -- Extra level font locking for java
 
-;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003 by David Ponce
+;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 by David Ponce
 
 ;; Author: David Ponce <david@dponce.com>
 ;; Maintainer: David Ponce <david@dponce.com>
 ;;             Paul Kinnucan <paulk@mathworks.com>
 ;; Created: September 28 1998
 ;; Keywords: java, tools
-;; VC: $Id: jde-java-font-lock.el,v 1.19 2003/07/15 11:58:45 paulk Exp $
+;; VC: $Id: jde-java-font-lock.el,v 1.23 2004/07/07 04:35:20 paulk Exp $
 
 ;; This file is not part of Emacs
 
@@ -98,6 +98,9 @@
 ;;; Code:
 (require 'font-lock)
 (require 'regexp-opt)
+(condition-case nil
+    (require 'cc-fonts)
+  (error nil))
 
 (defcustom jde-use-font-lock t
   "*Turn on font-locking if non-nil.
@@ -327,91 +330,6 @@ you have a lot of user's defined names don't use a value less than 1!"
 ;;;; Support for fontification inside javadocs and comments.
 ;;;;
 
-(defun jde-java-font-lock-remove-javadoc-keywords (keywords)
-  "Remove existing javadoc font lock keywords from KEYWORDS.
-That is those with \"@\" in their matcher regexp."
-  (let (kw matcher)
-    (while keywords
-      (setq matcher  (car keywords)
-            keywords (cdr keywords))
-      (if (not (and (consp matcher)
-                    (stringp (car matcher))
-                    (string-match "@" (car matcher))))
-          (setq kw (cons matcher kw))))
-    (nreverse kw)))
-
-(defconst jde-java-font-lock-comment-faces
-  '(font-lock-comment-face font-lock-doc-face)
-  "List of faces font-lock uses for comments.")
-
-(defmacro jde-java-font-lock-at-comment (pos)
-  "Return non-nil if POS is in a comment."
-  `(memq (get-text-property ,pos 'face)
-         jde-java-font-lock-comment-faces))
-
-(defsubst jde-java-font-lock-search-in-comment (regexp end)
-  "Search forward from point for regular expression REGEXP.
-Ensure matching occurs in a java comment.  Buffer position END bounds
-the search.  The match found must not extend after that position."
-  (let ((here (point))
-        ok b p)
-    (while (and (not ok)
-                (setq p (re-search-forward regexp end t)))
-      (setq b (match-beginning 0))
-      (setq ok (and (jde-java-font-lock-at-comment b)
-                    (< p (next-single-property-change
-                          b 'face nil (point-max))))))
-    (if ok
-        (point)
-      (goto-char here)
-      nil)))
-
-(defsubst jde-java-font-lock-search-in-javadoc (regexp end)
-  "Search forward from point for regular expression REGEXP.
-Ensure matching occurs in a javadoc comment.  Buffer position END
-bounds the search.  The match found must not extend after that
-position."
-  (let ((here (point))
-        b c ok md p)
-    (while (and (not ok) (setq p (re-search-forward regexp end t)))
-      (setq b  (match-beginning 0)
-            md (match-data)
-            ok (and (re-search-backward "^\\s-*\\(/[*][*]\\)" nil t)
-                    (jde-java-font-lock-at-comment
-                     (goto-char (setq c (match-beginning 1))))
-                    (forward-comment 1)
-                    (< p (point))
-                    (>= b c)
-                    (setq here p)))
-      (goto-char p))
-    (set-match-data md)
-    (goto-char here)
-    ok))
-
-(defun jde-java-font-lock-quote-matcher (end)
-  "Font lock matcher for comment enclosed in \`\'.
-Limit search to END position."
-  (jde-java-font-lock-search-in-comment
-   "`\\([^']*\\)'"
-   end))
-
-(defconst jde-java-font-lock-quote-keyword
-  '(jde-java-font-lock-quote-matcher
-    1 jde-java-font-lock-doc-tag-face t)
-  "Font lock keyword for comment enclosed in \`\'.")
-
-(defun jde-java-font-lock-html-ahref-matcher (end)
-  "Font lock matcher for HTML A HREF anchor in javadoc comments.
-Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   "<[Aa]\\s-+[Hh][Rr][Ee][Ff][^>]*>\\([^>]+\\)</[Aa]>"
-   end))
-
-(defconst jde-java-font-lock-html-ahref-keyword
-  '(jde-java-font-lock-html-ahref-matcher
-    1 jde-java-font-lock-link-face t)
-  "Font lock keyword for javadoc HTML A HREF anchor.")
-
 (eval-and-compile
   (defun jde-java-font-lock-html-tag-regexp (tag &rest aliases)
     "Return a regexp that matches HTML tag TAG.
@@ -440,107 +358,246 @@ expression in the returned regexp.  ALIASES are other names for TAG."
       (format "<\\(%s\\)>\\(%s\\)</\\(%s\\)>" tag-re hit-re tag-re)
       )))
 
-(defvar jde-java-font-lock-html-keywords nil
-  "List of HTML keywords defined so far.")
+(defconst jde-java-font-lock-comment-faces
+  '(font-lock-comment-face font-lock-doc-face)
+  "List of faces font-lock uses for comments.")
 
-(defmacro jde-java-font-lock-def-html-keyword (tag face)
-  "Define a font-lock keyword for HTML TAG.
+(defmacro jde-java-font-lock-at-comment (pos)
+  "Return non-nil if POS is in a comment."
+  `(memq (get-text-property ,pos 'face)
+         jde-java-font-lock-comment-faces))
+
+
+  (defsubst jde-java-font-lock-search-in-comment (regexp end)
+    "Search forward from point for regular expression REGEXP.
+Ensure matching occurs in a java comment.  Buffer position END bounds
+the search.  The match found must not extend after that position."
+    (let ((here (point))
+          ok b p)
+      (while (and (not ok)
+                  (setq p (re-search-forward regexp end t)))
+        (setq b (match-beginning 0))
+        (setq ok (and (jde-java-font-lock-at-comment b)
+                      (< p (next-single-property-change
+                            b 'face nil (point-max))))))
+      (if ok
+          (point)
+        (goto-char here)
+        nil)))
+
+(defun jde-java-font-lock-quote-matcher (end)
+  "Font lock matcher for comment enclosed in \`\'.
+Limit search to END position."
+  (jde-java-font-lock-search-in-comment
+   "`\\([^']*\\)'"
+   end))
+
+(defconst jde-java-font-lock-quote-keyword
+  '(jde-java-font-lock-quote-matcher
+    1 jde-java-font-lock-doc-tag-face t)
+  "Font lock keyword for comment enclosed in \`\'.")
+
+(eval-and-compile
+  (if (featurep 'cc-fonts)
+    
+      ;; Highlight javadoc comments through cc-fonts.
+      (defconst jde-java-font-lock-doc-comments
+        `(
+          ;; Fontify javadoc tags (including non official ones)
+          (,(concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
+                    "\\(@[" jde-java-font-lock-letter-or-digit "]+\\)")
+           2 jde-java-font-lock-doc-tag-face t)
+          ;; Fontify @param variable name
+          ("^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*@param\\>[ \t]*\\(\\sw+\\)?"
+           2 font-lock-variable-name-face prepend t)
+          ;; Fontify @exception or @throws exception type
+          ("^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*\
+@\\(exception\\|throws\\)\\>[ \t]*\\(\\S-+\\)?"
+           3 font-lock-type-face prepend t)
+          ;; Fontify @docRoot
+          ("{\\(@docRoot\\)}"
+           1 jde-java-font-lock-doc-tag-face t)
+          ;; Fontify @link
+          ("{\\(@link\\)\\>[ \t]+\\([^}]*\\)}"
+           (1 jde-java-font-lock-doc-tag-face t)
+           (2 jde-java-font-lock-link-face t))
+          ;; Fontify @see reference
+          (,(concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
+                    "@see\\>[ \t]*"
+                    "\\([.#" jde-java-font-lock-letter-or-digit "]+\\)")
+           2 jde-java-font-lock-code-face t)
+          ;; Fontify the text of a HREF anchor
+          ("<[Aa]\\s-+[Hh][Rr][Ee][Ff][^>]*>\\([^>]+\\)</[Aa]>"
+           1 jde-java-font-lock-link-face t)
+          ;; Fontify other HTML tags
+          (,(jde-java-font-lock-html-tag-regexp "b")
+           2 jde-java-font-lock-bold-face t)
+          (,(jde-java-font-lock-html-tag-regexp "strong")
+           2 jde-java-font-lock-bold-face t)
+          (,(jde-java-font-lock-html-tag-regexp "i")
+           2 jde-java-font-lock-italic-face t)
+          (,(jde-java-font-lock-html-tag-regexp "em")
+           2 jde-java-font-lock-italic-face t)
+          (,(jde-java-font-lock-html-tag-regexp "u")
+           2 jde-java-font-lock-underline-face t)
+          (,(jde-java-font-lock-html-tag-regexp "code")
+           2 jde-java-font-lock-code-face t)
+          (,(jde-java-font-lock-html-tag-regexp "pre")
+           2 jde-java-font-lock-pre-face t)
+          )
+        "Keywords highlighted in javadoc comments.")
+  
+    ;; Highlight javadoc comments through JDEE's own support
+    (defun jde-java-font-lock-remove-javadoc-keywords (keywords)
+      "Remove existing javadoc font lock keywords from KEYWORDS.
+That is those with \"@\" in their matcher regexp."
+      (let (kw matcher)
+        (while keywords
+          (setq matcher  (car keywords)
+                keywords (cdr keywords))
+          (if (not (and (consp matcher)
+                        (stringp (car matcher))
+                        (string-match "@" (car matcher))))
+              (setq kw (cons matcher kw))))
+        (nreverse kw)))
+
+    (defsubst jde-java-font-lock-search-in-javadoc (regexp end)
+      "Search forward from point for regular expression REGEXP.
+Ensure matching occurs in a javadoc comment.  Buffer position END
+bounds the search.  The match found must not extend after that
+position."
+      (let ((here (point))
+            b c ok md p)
+        (while (and (not ok) (setq p (re-search-forward regexp end t)))
+          (setq b  (match-beginning 0)
+                md (match-data)
+                ok (and (re-search-backward "^\\s-*\\(/[*][*]\\)" nil t)
+                        (jde-java-font-lock-at-comment
+                         (goto-char (setq c (match-beginning 1))))
+                        (forward-comment 1)
+                        (< p (point))
+                        (>= b c)
+                        (setq here p)))
+          (goto-char p))
+        (set-match-data md)
+        (goto-char here)
+        ok))
+
+    (defun jde-java-font-lock-html-ahref-matcher (end)
+      "Font lock matcher for HTML A HREF anchor in javadoc comments.
+Limit search to END position."
+      (jde-java-font-lock-search-in-javadoc
+       "<[Aa]\\s-+[Hh][Rr][Ee][Ff][^>]*>\\([^>]+\\)</[Aa]>"
+       end))
+
+    (defconst jde-java-font-lock-html-ahref-keyword
+      '(jde-java-font-lock-html-ahref-matcher
+        1 jde-java-font-lock-link-face t)
+      "Font lock keyword for javadoc HTML A HREF anchor.")
+
+
+    (defvar jde-java-font-lock-html-keywords nil
+      "List of HTML keywords defined so far.")
+
+    (defmacro jde-java-font-lock-def-html-keyword (tag face)
+      "Define a font-lock keyword for HTML TAG.
 Data inside TAG will be highlighted with FACE.
 A new keyword is pushed into `jde-java-font-lock-html-keywords'."
-  (let* ((matcher (intern (format "jde-java-font-lock-html-%s-matcher" tag))))
-;         (keyword (intern (format "jde-java-font-lock-html-%s-keyword" tag))))
-    `(progn
-       (add-to-list 'jde-java-font-lock-html-keywords '(,matcher 2 ,face t))
-       (defun ,matcher (end)
-         (jde-java-font-lock-search-in-javadoc
-          ,(jde-java-font-lock-html-tag-regexp tag) end)))))
+      (let* ((matcher (intern (format "jde-java-font-lock-html-%s-matcher" tag))))
+        `(progn
+           (add-to-list 'jde-java-font-lock-html-keywords '(,matcher 2 ,face t))
+           (defun ,matcher (end)
+             (jde-java-font-lock-search-in-javadoc
+              ,(jde-java-font-lock-html-tag-regexp tag) end)))))
 
-(jde-java-font-lock-def-html-keyword "b" jde-java-font-lock-bold-face)
-(jde-java-font-lock-def-html-keyword "strong" jde-java-font-lock-bold-face)
-(jde-java-font-lock-def-html-keyword "i" jde-java-font-lock-italic-face)
-(jde-java-font-lock-def-html-keyword "em" jde-java-font-lock-italic-face)
-(jde-java-font-lock-def-html-keyword "u" jde-java-font-lock-underline-face)
-(jde-java-font-lock-def-html-keyword "code" jde-java-font-lock-code-face)
-(jde-java-font-lock-def-html-keyword "pre" jde-java-font-lock-pre-face)
+    (jde-java-font-lock-def-html-keyword "b" jde-java-font-lock-bold-face)
+    (jde-java-font-lock-def-html-keyword "strong" jde-java-font-lock-bold-face)
+    (jde-java-font-lock-def-html-keyword "i" jde-java-font-lock-italic-face)
+    (jde-java-font-lock-def-html-keyword "em" jde-java-font-lock-italic-face)
+    (jde-java-font-lock-def-html-keyword "u" jde-java-font-lock-underline-face)
+    (jde-java-font-lock-def-html-keyword "code" jde-java-font-lock-code-face)
+    (jde-java-font-lock-def-html-keyword "pre" jde-java-font-lock-pre-face)
 
-(defun jde-java-font-lock-javadoc-tag-matcher (end)
-  "Font lock matcher for javadoc tags.
+    (defun jde-java-font-lock-javadoc-tag-matcher (end)
+      "Font lock matcher for javadoc tags.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   (eval-when-compile
-     (concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
-             "\\(@[" jde-java-font-lock-letter-or-digit "]+\\)"))
-   end))
+      (jde-java-font-lock-search-in-javadoc
+       (eval-when-compile
+         (concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
+                 "\\(@[" jde-java-font-lock-letter-or-digit "]+\\)"))
+       end))
 
-(defconst jde-java-font-lock-javadoc-tag-keyword
-  '(jde-java-font-lock-javadoc-tag-matcher
-    2 jde-java-font-lock-doc-tag-face t)
-  "Font lock keyword for javadoc tags.")
+    (defconst jde-java-font-lock-javadoc-tag-keyword
+      '(jde-java-font-lock-javadoc-tag-matcher
+        2 jde-java-font-lock-doc-tag-face t)
+      "Font lock keyword for javadoc tags.")
 
-(defun jde-java-font-lock-javadoc-docroot-matcher (end)
-  "Font lock matcher for javadoc @docRoot tags.
+    (defun jde-java-font-lock-javadoc-docroot-matcher (end)
+      "Font lock matcher for javadoc @docRoot tags.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   "{\\(@docRoot\\)}"
-   end))
+      (jde-java-font-lock-search-in-javadoc
+       "{\\(@docRoot\\)}"
+       end))
 
-(defconst jde-java-font-lock-javadoc-docroot-keyword
-  '(jde-java-font-lock-javadoc-docroot-matcher
-    1 jde-java-font-lock-doc-tag-face t)
-  "Font lock keyword for javadoc @docRoot tags.")
+    (defconst jde-java-font-lock-javadoc-docroot-keyword
+      '(jde-java-font-lock-javadoc-docroot-matcher
+        1 jde-java-font-lock-doc-tag-face t)
+      "Font lock keyword for javadoc @docRoot tags.")
 
-(defun jde-java-font-lock-javadoc-link-matcher (end)
-  "Font lock matcher for javadoc @link tags.
+    (defun jde-java-font-lock-javadoc-link-matcher (end)
+      "Font lock matcher for javadoc @link tags.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   "{\\(@link\\)\\>[ \t]+\\([^}]*\\)}"
-   end))
+      (jde-java-font-lock-search-in-javadoc
+       "{\\(@link\\)\\>[ \t]+\\([^}]*\\)}"
+       end))
 
-(defconst jde-java-font-lock-javadoc-link-keyword
-  '(jde-java-font-lock-javadoc-link-matcher
-    (1 jde-java-font-lock-doc-tag-face t)
-    (2 jde-java-font-lock-link-face t))
-  "Font lock keyword for javadoc @link tags.")
+    (defconst jde-java-font-lock-javadoc-link-keyword
+      '(jde-java-font-lock-javadoc-link-matcher
+        (1 jde-java-font-lock-doc-tag-face t)
+        (2 jde-java-font-lock-link-face t))
+      "Font lock keyword for javadoc @link tags.")
 
-(defun jde-java-font-lock-javadoc-see-ref-matcher (end)
-  "Font lock matcher for javadoc @see references.
+    (defun jde-java-font-lock-javadoc-see-ref-matcher (end)
+      "Font lock matcher for javadoc @see references.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   (eval-when-compile
-     (concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
-             "@see\\>[ \t]*"
-             "\\([.#" jde-java-font-lock-letter-or-digit "]+\\)"))
-   end))
+      (jde-java-font-lock-search-in-javadoc
+       (eval-when-compile
+         (concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
+                 "@see\\>[ \t]*"
+                 "\\([.#" jde-java-font-lock-letter-or-digit "]+\\)"))
+       end))
 
-(defconst jde-java-font-lock-javadoc-see-ref-keyword
-  '(jde-java-font-lock-javadoc-see-ref-matcher
-    2 jde-java-font-lock-code-face t)
-  "Font lock keyword for javadoc @see references.")
+    (defconst jde-java-font-lock-javadoc-see-ref-keyword
+      '(jde-java-font-lock-javadoc-see-ref-matcher
+        2 jde-java-font-lock-code-face t)
+      "Font lock keyword for javadoc @see references.")
 
-(defun jde-java-font-lock-javadoc-param-name-matcher (end)
-  "Font lock matcher for javadoc @param names.
+    (defun jde-java-font-lock-javadoc-param-name-matcher (end)
+      "Font lock matcher for javadoc @param names.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*@param\\>[ \t]*\\(\\sw+\\)?"
-   end))
+      (jde-java-font-lock-search-in-javadoc
+       "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*@param\\>[ \t]*\\(\\sw+\\)?"
+       end))
 
-(defconst jde-java-font-lock-javadoc-param-name-keyword
-  '(jde-java-font-lock-javadoc-param-name-matcher
-    2 font-lock-variable-name-face prepend t)
-  "Font lock keyword for javadoc @param names.")
+    (defconst jde-java-font-lock-javadoc-param-name-keyword
+      '(jde-java-font-lock-javadoc-param-name-matcher
+        2 font-lock-variable-name-face prepend t)
+      "Font lock keyword for javadoc @param names.")
 
-(defun jde-java-font-lock-javadoc-exception-type-matcher (end)
-  "Font lock matcher for javadoc exception types.
+    (defun jde-java-font-lock-javadoc-exception-type-matcher (end)
+      "Font lock matcher for javadoc exception types.
 Limit search to END position."
-  (jde-java-font-lock-search-in-javadoc
-   "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*\
+      (jde-java-font-lock-search-in-javadoc
+       "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*\
 @\\(exception\\|throws\\)\\>[ \t]*\\(\\S-+\\)?"
-   end))
+       end))
 
-(defconst jde-java-font-lock-javadoc-exception-type-keyword
-  '(jde-java-font-lock-javadoc-exception-type-matcher
-    3 font-lock-type-face prepend t)
-  "Font lock keyword for javadoc exception types.")
+    (defconst jde-java-font-lock-javadoc-exception-type-keyword
+      '(jde-java-font-lock-javadoc-exception-type-matcher
+        3 font-lock-type-face prepend t)
+      "Font lock keyword for javadoc exception types.")
+
+    ))
 
 ;;;;
 ;;;; Support for fontification of user's defined names.
@@ -735,213 +792,171 @@ expressions."
           (font-lock-mode 1)
           (message "JDEE refontify  buffer %s...done" b))))))
 
-(defun jde-java-font-lock-keywords-with-cc-fonts (&optional rebuild)
-  "JDEE's extra level font lock keywords used with cc-fonts.
+(defun jde-java-font-lock-keywords (&optional rebuild)
+  "JDEE's extra level font lock keywords.
 If optional REBUILD flag is non-nil create a new cache of regular
 expressions."
-  (append
-
-   java-font-lock-keywords-3
-    
-   ;; Fontify user's defined names
-   (mapcar #'(lambda (e)
-               (list
-                (c-make-font-lock-search-function
-                 (car e)
-                 (list 0 (cdr e) t))))
-           (jde-java-font-lock-api-keywords rebuild))
-
-   (list
-            
-    ;; Fontify modifiers.
-    `(,(c-make-font-lock-search-function
-        jde-java-font-lock-modifier-regexp
-        '(0 jde-java-font-lock-modifier-face t)))
-     
-    `(,(c-make-font-lock-search-function
-        "\\<\\(false\\|null\\|true\\)\\>"
-        '(1 jde-java-font-lock-constant-face t)))
-     
-    ;; Fontify default and assert as keywords
-    `(,(c-make-font-lock-search-function
-        "\\<\\(default\\|assert\\)\\>"
-        '(1 'font-lock-keyword-face t)))
-     
-    ;; Fontify const and goto with warning face. These keywords are
-    ;; reserved, even though they are not currently used.
-    `(,(c-make-font-lock-search-function
-        "\\<\\(const\\|goto\\)\\>"
-        '(1 'font-lock-warning-face t)))
-
-    ;; Fontify numbers
-    `(,(c-make-font-lock-search-function
-        jde-java-font-lock-number-regexp
-        '(0 jde-java-font-lock-number-face t)))
-
-    ;; Fontify operators
+  (if (featurep 'cc-fonts)
+      
+      ;; Through cc-fonts support.
+      (append
+       java-font-lock-keywords-3
+       ;; Fontify user's defined names
+       (mapcar #'(lambda (e)
+                   (list
+                    (c-make-font-lock-search-function
+                     (car e)
+                     (list 0 (cdr e) t))))
+               (jde-java-font-lock-api-keywords rebuild))
+       (list
+        ;; Fontify modifiers.
+        `(,(c-make-font-lock-search-function
+            jde-java-font-lock-modifier-regexp
+            '(0 jde-java-font-lock-modifier-face t)))
+        `(,(c-make-font-lock-search-function
+            "\\<\\(false\\|null\\|true\\)\\>"
+            '(1 jde-java-font-lock-constant-face t)))
+        ;; Fontify default and assert as keywords
+        `(,(c-make-font-lock-search-function
+            "\\<\\(default\\|assert\\)\\>"
+            '(1 'font-lock-keyword-face t)))
+        ;; Fontify const and goto with warning face. These keywords are
+        ;; reserved, even though they are not currently used.
+        `(,(c-make-font-lock-search-function
+            "\\<\\(const\\|goto\\)\\>"
+            '(1 'font-lock-warning-face t)))
+        ;; Fontify numbers
+        `(,(c-make-font-lock-search-function
+            jde-java-font-lock-number-regexp
+            '(0 jde-java-font-lock-number-face t)))
+        ;; Fontify operators
 ;;;     `(,(c-make-font-lock-search-function
 ;;;         jde-java-font-lock-operator-regexp
 ;;;         '(0 jde-java-font-lock-operator-face t)))
-     
-    ;; Fontify capitalised identifiers as constant
-    `(,jde-java-font-lock-capital-id-regexp
-      1 jde-java-font-lock-constant-face)
-
-    ;; Fontify text between `' in comments
-    jde-java-font-lock-quote-keyword
-
-    ;; Fontify javadoc tags (including non official ones)
-    jde-java-font-lock-javadoc-tag-keyword
-    ;; Fontify @param variable name
-    jde-java-font-lock-javadoc-param-name-keyword
-    ;; Fontify @exception or @throws exception type
-    jde-java-font-lock-javadoc-exception-type-keyword
-    ;; Fontify @docRoot
-    jde-java-font-lock-javadoc-docroot-keyword
-    ;; Fontify @link
-    jde-java-font-lock-javadoc-link-keyword
-    ;; Fontify @see reference
-    jde-java-font-lock-javadoc-see-ref-keyword
-    ;; Fontify the text of a HREF anchor
-    jde-java-font-lock-html-ahref-keyword
-     
-    )
+        ;; Fontify capitalised identifiers as constant
+        `(,jde-java-font-lock-capital-id-regexp
+          1 jde-java-font-lock-constant-face)
+        ;; Fontify text between `' in comments
+        jde-java-font-lock-quote-keyword
+        ;; Fontify javadoc comments
+        '((lambda (limit)
+            (c-font-lock-doc-comments
+                "/\\*\\*" limit
+              jde-java-font-lock-doc-comments)))
+        )
+       )
     
-   ;; Fontify other HTML tags
-   jde-java-font-lock-html-keywords
-    
-   ))
-
-(defun jde-java-font-lock-keywords-default (&optional rebuild)
-  "Default JDEE's extra level font lock keywords.
-If optional REBUILD flag is non-nil create a new cache of regular
-expressions."
-  (append
-
-   ;; Feature scoping: These must come first or the Special
-   ;; constants, Modifiers and Packages from keywords-1 will catch
-   ;; them.
+    ;; Through JDEE's own support
+    (append
+     ;; Feature scoping: These must come first or the Special
+     ;; constants, Modifiers and Packages from keywords-1 will catch
+     ;; them.
 ;;; Compatibility
-   (if (featurep 'xemacs)
-       (list
+     (if (featurep 'xemacs)
+         (list
             
-        ;; Special keywords and constants
-        '("\\<\\(this\\|super\\)\\>"
-          (1 font-lock-keyword-face))
-        '("\\<\\(false\\|null\\|true\\)\\>"
-          (1 jde-java-font-lock-constant-face))
-        ))
+          ;; Special keywords and constants
+          '("\\<\\(this\\|super\\)\\>"
+            (1 font-lock-keyword-face))
+          '("\\<\\(false\\|null\\|true\\)\\>"
+            (1 jde-java-font-lock-constant-face))
+          ))
        
-   (list
-
-    ;; Fontify default as keyword
-    '("\\<\\(default\\)\\>" (1 font-lock-keyword-face))
-     
-    ;; Fontify assert as keyword
-    '("\\<\\(assert\\)\\>" (1 font-lock-keyword-face))
-
-    ;; Fontify const and goto with warning face. These keywords are
-    ;; reserved, even though they are not currently used.
-    '("\\<\\(const\\|goto\\)\\>" (1 font-lock-warning-face))
-
-    ;; Fontify modifiers.
-    (cons jde-java-font-lock-modifier-regexp
-          'jde-java-font-lock-modifier-face)
-        
-    ;; Fontify package directives
-    '("\\<\\(package\\)\\>\\s-+\\(\\sw+\\)"
-      (1 font-lock-keyword-face)
-      (2 jde-java-font-lock-package-face nil t)
-      ("\\=\\.\\(\\sw+\\)" nil nil
-       (1 jde-java-font-lock-package-face nil t)))
-        
-    ;; Fontify import directives
-    '("\\<\\(import\\)\\>\\s-+\\(\\sw+\\)"
-      (1 font-lock-keyword-face)
-      (2 (if (char-equal (char-after (match-end 0)) ?\.)
-             'jde-java-font-lock-package-face
-           'font-lock-type-face))
-      ("\\=\\.\\(\\*\\|\\sw+\\)" nil nil
-       (1 (if (char-equal (char-after (match-end 0)) ?\.)
-              'jde-java-font-lock-package-face
-            (if (char-equal (char-before (match-end 0)) ?\*)
-                'jde-java-font-lock-number-face
-              'font-lock-type-face)))))
-    )
-
-   ;; Fontify user's defined names
-   (jde-java-font-lock-api-keywords rebuild)
-       
-;;; Compatibility
-   (if (featurep 'xemacs)
-       java-font-lock-keywords-2
-     ;; Remove existing javadoc font lock keywords from GNU Emacs
-     ;; `java-font-lock-keywords-3'
-     (jde-java-font-lock-remove-javadoc-keywords
-      java-font-lock-keywords-3))
-
-;;; Compatibility
-   (unless (featurep 'xemacs)
-     ;; GNU Emacs don't fontify capitalized types so do it
      (list
-      (list
-       (concat "\\<\\([" jde-java-font-lock-capital-letter "]\\sw*\\)\\>"
-               "\\([ \t]*\\[[ \t]*\\]\\)*"
-               "\\([ \t]*\\sw\\)")
-       '(font-lock-match-c-style-declaration-item-and-skip-to-next
-         (goto-char (match-beginning 3))
-         (goto-char (match-beginning 3))
-         (1 (if (match-beginning 2)
-                font-lock-function-name-face
-              font-lock-variable-name-face))))
-      (cons
-       (concat "\\<\\([" jde-java-font-lock-capital-letter "]\\sw*\\)\\>"
-               "\\([ \t]*\\[[ \t]*\\]\\)*"
-               "\\([ \t]*\\sw\\)")
-       '(1 font-lock-type-face))
-            
-      '("\\<\\(new\\|instanceof\\)\\>[ \t]+\\(\\sw+\\)"
-        2 font-lock-type-face)))
+      ;; Fontify default as keyword
+      '("\\<\\(default\\)\\>" (1 font-lock-keyword-face))
+      ;; Fontify assert as keyword
+      '("\\<\\(assert\\)\\>" (1 font-lock-keyword-face))
+      ;; Fontify const and goto with warning face. These keywords are
+      ;; reserved, even though they are not currently used.
+      '("\\<\\(const\\|goto\\)\\>" (1 font-lock-warning-face))
+      ;; Fontify modifiers.
+      (cons jde-java-font-lock-modifier-regexp
+            'jde-java-font-lock-modifier-face)
+      ;; Fontify package directives
+      '("\\<\\(package\\)\\>\\s-+\\(\\sw+\\)"
+        (1 font-lock-keyword-face)
+        (2 jde-java-font-lock-package-face nil t)
+        ("\\=\\.\\(\\sw+\\)" nil nil
+         (1 jde-java-font-lock-package-face nil t)))
+      ;; Fontify import directives
+      '("\\<\\(import\\)\\>\\s-+\\(\\sw+\\)"
+        (1 font-lock-keyword-face)
+        (2 (if (equal (char-after (match-end 0)) ?\.)
+               'jde-java-font-lock-package-face
+             'font-lock-type-face))
+        ("\\=\\.\\(\\*\\|\\sw+\\)" nil nil
+         (1 (if (equal (char-after (match-end 0)) ?\.)
+                'jde-java-font-lock-package-face
+              (if (equal (char-before (match-end 0)) ?\*)
+                  'jde-java-font-lock-number-face
+                'font-lock-type-face)))))
+      )
+     ;; Fontify user's defined names
+     (jde-java-font-lock-api-keywords rebuild)
+       
+;;; Compatibility
+     (if (featurep 'xemacs)
+         java-font-lock-keywords-2
+       ;; Remove existing javadoc font lock keywords from GNU Emacs
+       ;; `java-font-lock-keywords-3'
+       (jde-java-font-lock-remove-javadoc-keywords
+        java-font-lock-keywords-3))
 
-   ;; Some extra fontification
-   (list
-        
-    ;; Fontify numbers
-    (cons jde-java-font-lock-number-regexp
-          'jde-java-font-lock-number-face)
+;;; Compatibility
+     (unless (featurep 'xemacs)
+       ;; GNU Emacs don't fontify capitalized types so do it
+       (list
+        (list
+         (concat "\\<\\([" jde-java-font-lock-capital-letter "]\\sw*\\)\\>"
+                 "\\([ \t]*\\[[ \t]*\\]\\)*"
+                 "\\([ \t]*\\sw\\)")
+         '(font-lock-match-c-style-declaration-item-and-skip-to-next
+           (goto-char (match-beginning 3))
+           (goto-char (match-beginning 3))
+           (1 (if (match-beginning 2)
+                  font-lock-function-name-face
+                font-lock-variable-name-face))))
+        (cons
+         (concat "\\<\\([" jde-java-font-lock-capital-letter "]\\sw*\\)\\>"
+                 "\\([ \t]*\\[[ \t]*\\]\\)*"
+                 "\\([ \t]*\\sw\\)")
+         '(1 font-lock-type-face))
+        '("\\<\\(new\\|instanceof\\)\\>[ \t]+\\(\\sw+\\)"
+          2 font-lock-type-face)))
 
-    ;; Fontify operators
+     ;; Some extra fontification
+     (list
+      ;; Fontify numbers
+      (cons jde-java-font-lock-number-regexp
+            'jde-java-font-lock-number-face)
+      ;; Fontify operators
 ;;;      (cons jde-java-font-lock-operator-regexp
 ;;;            'jde-java-font-lock-operator-face)
-     
-    ;; Fontify capitalised identifiers as constant
-    (cons jde-java-font-lock-capital-id-regexp
-          '(1 jde-java-font-lock-constant-face))
-
-    ;; Fontify text between `' in comments
-    jde-java-font-lock-quote-keyword
-
-    ;; Fontify javadoc tags (including non official ones)
-    jde-java-font-lock-javadoc-tag-keyword
-    ;; Fontify @param variable name
-    jde-java-font-lock-javadoc-param-name-keyword
-    ;; Fontify @exception or @throws exception type
-    jde-java-font-lock-javadoc-exception-type-keyword
-    ;; Fontify @docRoot
-    jde-java-font-lock-javadoc-docroot-keyword
-    ;; Fontify @link
-    jde-java-font-lock-javadoc-link-keyword
-    ;; Fontify @see reference
-    jde-java-font-lock-javadoc-see-ref-keyword
-    ;; Fontify the text of a HREF anchor
-    jde-java-font-lock-html-ahref-keyword
-     
-    )
-    
-   ;; Fontify other HTML tags
-   jde-java-font-lock-html-keywords
-    
-   ))
+      ;; Fontify capitalised identifiers as constant
+      (cons jde-java-font-lock-capital-id-regexp
+            '(1 jde-java-font-lock-constant-face))
+      ;; Fontify text between `' in comments
+      jde-java-font-lock-quote-keyword
+      ;; Fontify javadoc tags (including non official ones)
+      jde-java-font-lock-javadoc-tag-keyword
+      ;; Fontify @param variable name
+      jde-java-font-lock-javadoc-param-name-keyword
+      ;; Fontify @exception or @throws exception type
+      jde-java-font-lock-javadoc-exception-type-keyword
+      ;; Fontify @docRoot
+      jde-java-font-lock-javadoc-docroot-keyword
+      ;; Fontify @link
+      jde-java-font-lock-javadoc-link-keyword
+      ;; Fontify @see reference
+      jde-java-font-lock-javadoc-see-ref-keyword
+      ;; Fontify the text of a HREF anchor
+      jde-java-font-lock-html-ahref-keyword
+      )
+     ;; Fontify other HTML tags
+     jde-java-font-lock-html-keywords
+     )
+    ))
 
 ;;;###autoload
 (defun jde-java-font-lock-setup-keywords (&optional rebuild)
@@ -954,10 +969,7 @@ expressions."
        (setq rebuild t))
   
   ;; Setup the JDEE's extra font lock keywords.
-  (setq java-font-lock-keywords-4
-        (if (featurep 'cc-fonts)
-            (jde-java-font-lock-keywords-with-cc-fonts rebuild)
-          (jde-java-font-lock-keywords-default rebuild)))
+  (setq java-font-lock-keywords-4 (jde-java-font-lock-keywords rebuild))
   
   ;; Update fontification of buffers in `java-mode' and `jde-mode'.
   (when (interactive-p)
@@ -971,11 +983,20 @@ expressions."
   (let ((java-defaults 
          (if (featurep 'xemacs)
              (get 'java-mode 'font-lock-defaults)
-           (cdr (assq 'java-mode font-lock-defaults-alist)))))
+           ;;; To avoid compilation warning, replace obsolete variable,
+	   ;;; font-lock-defaults-alist, with its value for java-mode.
+           ;;; (cdr (assq 'java-mode font-lock-defaults-alist)))))
+	   ;;; Paul Kinnucan.
+	   '((java-font-lock-keywords 
+	      java-font-lock-keywords-1
+	      java-font-lock-keywords-2 
+	      java-font-lock-keywords-3)
+	     nil nil ((?_ . "w") (?$ . "w")) nil
+	     (font-lock-mark-block-function . mark-defun)))))
     (cons (append (car java-defaults) '(java-font-lock-keywords-4))
           (cdr java-defaults)))
-  "Defaults for Font Lock mode specified by the major mode.
-Add `java-font-lock-keywords-4' level to Java `font-lock-defaults'.")
+  "Defaults for coloring Java keywords in jde-mode. The defaults
+consist of the java-mode defaults plus `java-font-lock-keywords-4'.")
 
 ;;;;
 ;;;; Mode hook to setup syntax coloring.
@@ -1005,7 +1026,10 @@ standard `java-mode'."
     ;; if `jde-use-font-lock' is nil).
     (let ((major-mode (if jde-use-font-lock major-mode 'java-mode)))
       (if (featurep 'xemacs)
-          (font-lock-set-defaults t)
+	  ;; The following is intended to avoid a byte-compilation warning
+	  ;; when compiling this file under Emacs. The Emacs version of
+	  ;; font-lock-set-defaults accepts no arguments.
+          (apply 'font-lock-set-defaults (list t))
         (if global-font-lock-mode
             (turn-on-font-lock-if-enabled))))
     ;; Always turn on font locking if `jde-use-font-lock' is non-nil.
@@ -1021,6 +1045,18 @@ standard `java-mode'."
 
 ;;
 ;; $Log: jde-java-font-lock.el,v $
+;; Revision 1.23  2004/07/07 04:35:20  paulk
+;; Made changes to eliminate byte-compilation warnings.
+;;
+;; Revision 1.22  2004/05/28 04:34:18  paulk
+;; Remove DOS line endings.
+;;
+;; Revision 1.21  2004/05/14 04:03:27  paulk
+;; Update to support c-doc-face-name if defined. Thanks to David Ponce.
+;;
+;; Revision 1.20  2004/03/03 03:14:28  paulk
+;; Fix bug that causes a (wrong-type-argument integerp nil) error when entering an import statement in a new Java file. Thanks to David Ponce.
+;;
 ;; Revision 1.19  2003/07/15 11:58:45  paulk
 ;; Remove CRs.
 ;;
