@@ -1,7 +1,7 @@
 ;; JDE-PARSE-CLASS.EL --- Parse a Java class file.
-;; $Revision: 1.7 $ $Date: 2003/06/19 17:01:39 $
+;; $Revision: 1.8 $ $Date: 2004/07/09 05:17:20 $
 ;;
-;; Copyright (C) 2002 Andrew Hyatt
+;; Copyright (C) 2002, 2004 Andrew Hyatt
 ;;
 ;; Author: Andrew Hyatt <andy_jde@thehyatts.net>
 ;; Maintainers: Andrew Hyatt and Paul Kinnucan
@@ -26,7 +26,7 @@
 ;; LCD Archive Entry:
 ;; jde-parse-class|Andrew Hyatt|
 ;; |Parse a Java class file to get xref info for the JDEE.
-;; |$Date: 2003/06/19 17:01:39 $|$Revision: 1.7 $|~/packages/jde-parse-class.el
+;; |$Date: 2004/07/09 05:17:20 $|$Revision: 1.8 $|~/packages/jde-parse-class.el
 
 ;;; Commentary:
 
@@ -508,7 +508,6 @@ returns ('f 'g)"
 of the constants) and a vector of all constants"
   (let* ((count (- (jde-parse-class-get-2byte 9) 1))
          (const-vec (make-vector count '())))
-    (setq i 0)
     (goto-char 11) ;; start of constants
     (dotimes (i count const-vec)
       (let ((const (jde-parse-class-get-next-constant)))
@@ -792,6 +791,14 @@ must be calculated at runtime.")
 (provide 'jde-parse-class)
 
 ;; $Log: jde-parse-class.el,v $
+;; Revision 1.8  2004/07/09 05:17:20  paulk
+;; Eliminated initialization of loop variable i to 0 in
+;; jde-parse-class-get-constants. It does not seem necessssary as dotimes
+;; initializes the variable itself to 0. Further, the initialization
+;; turned i into a free variable, causing a compiler warning. I tested
+;; jde-parse-class-get-constants before and after this change and the
+;; change made no difference.
+;;
 ;; Revision 1.7  2003/06/19 17:01:39  ahyatt
 ;; Now compatible with emacs and xemacs versions without MULE
 ;;
